==> fastone_ucloud-0.1.0.tar.gz: fastone_ucloud-0.1.0/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', ]

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Xiaofei Chen",
    author_email='neocxf@qq.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="ucloud deployment services that work on FastOne stack for computing service",
    entry_points={
        'console_scripts': [
            'fastone_ucloud=fastone_ucloud.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='fastone_ucloud',
    name='fastone_ucloud',
    packages=find_packages(include=['fastone_ucloud', 'fastone_ucloud.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/neocxf/fastone_ucloud',
    version='0.1.0',
    zip_safe=False,
)

==> fastone_ucloud-0.1.1.tar.gz: fastone_ucloud-0.1.1/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', ]

setup_requirements = ['pytest-runner', 'wheel']

test_requirements = ['pytest>=3', ]

setup(
    author="Xiaofei Chen",
    author_email='neocxf@qq.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="ucloud deployment services that work on FastOne stack for computing service",
    entry_points={
        'console_scripts': [
            'fastone-ucloud=fastone_ucloud.cli:cli',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='fastone_ucloud',
    name='fastone_ucloud',
    packages=find_packages(include=['fastone_ucloud', 'fastone_ucloud.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/neocxf/fastone_ucloud',
    version='0.1.1',
    zip_safe=False,
)
